@@ -19,8 +19,6 @@
  * ***********************************************************************
  */
 
-#ifndef VRENGD
-
 #include "global.h"
 
 #include <X11/Intrinsic.h>
@@ -43,13 +41,14 @@
 #endif
 
 #include "net.h"
-#include "zv.h"
-#include "wobject.h"
+#include "vgl.h"
+#include "wo.h"
 #include "world.h"
 #include "keys.h"
 #include "move.h"		/* Move */
 #include "user.h"		/* FOVY* */
-#include "helpers.h"
+#include "app.h"
+#include "vnc.h"
 
 #include "gui.h"
 #include "guiImpl.hh"
@@ -96,7 +95,7 @@ static Widget CreateButtonAndOptionMenu(Widget menubar, String name);
 static void SetLabelValue(Widget ww, const char *value);
 static void SetTextFieldValue(Widget ww, const char *s);
 static char *GetTextFieldValue(Widget ww);
-static void SetTextAreaValue(Widget ww, const char *s, boolean add_at_the_end);
+static void SetTextAreaValue(Widget ww, const char *s, bool add_at_the_end);
 static Boolean GetToggleValue(Widget togglew);
 static void SetToggleValue(Widget togglew, Boolean state);
 #ifndef WANT_MOTIF
@@ -106,15 +105,16 @@ static void initTogglePixmap(Widget toplevel);
 #endif
 
 
-GuiWidgets::GuiWidgets(GUI *pgui) {
+GuiWidgets::GuiWidgets(GUI &_gui) : gui(_gui) {
   Widget btn;
-  gui = pgui;	// points to the containing GUI class
+  vnc = NULL;
+  //vnc_dialog = NULL;
 
   // Creates the Main Window (also called the "Main Frame")
 #if WANT_MOTIF
-  frame = XtCreateManagedWidget("frame", xmFormWidgetClass, gui->toplevel, NULL, 0);
+  frame = XtCreateManagedWidget("frame", xmFormWidgetClass, gui.toplevel, NULL, 0);
 #else
-  frame = XtCreateManagedWidget("frame", panedWidgetClass, gui->toplevel, NULL, 0);
+  frame = XtCreateManagedWidget("frame", panedWidgetClass, gui.toplevel, NULL, 0);
 #endif
 
   // MenuBar of the Appli
@@ -131,14 +131,10 @@ GuiWidgets::GuiWidgets(GUI *pgui) {
 #endif
 
   CreateButton(menuBar, "Quit", GUI::quit, 0);
-#if 0
-  CreateButton(menuBar, "Edit", GUI::edit, 0);
-#endif
   CreateButton(menuBar, "Back", GUI::back, 0);
   CreateButton(menuBar, "Forward", GUI::forward, 0);
   CreateButton(menuBar, "Home", GUI::home, 0);
 #if 0
-  CreateButton(menuBar, "Views", GUI::views, 0);
   CreateButton(menuBar, "Bookmarks", GUI::bookmarks, 0);
 #endif
 
@@ -217,14 +213,14 @@ GuiWidgets::GuiWidgets(GUI *pgui) {
 #if WANT_MOTIF
   glzone = 
     XtVaCreateManagedWidget("glzone", xmDrawingAreaWidgetClass, workArea,
-			    XmNwidth, (XtArgVal)resources.width3D,
-			    XmNheight, (XtArgVal)resources.height3D, 
+			    XmNwidth, (XtArgVal)options->width3D,
+			    XmNheight, (XtArgVal)options->height3D, 
 			    TOP_F, LEFT_F, BOTTOM_F, NULL);
 #else
   glzone = 
     XtVaCreateManagedWidget("glzone", labelWidgetClass, workArea,
-			    XtNwidth, (XtArgVal)resources.width3D,
-			    XtNheight, (XtArgVal)resources.height3D, 
+			    XtNwidth, (XtArgVal)options->width3D,
+			    XtNheight, (XtArgVal)options->height3D, 
 			    XtNlabel, PLEASE_WAIT,
 			    NULL);
 #endif
@@ -240,10 +236,10 @@ GuiWidgets::GuiWidgets(GUI *pgui) {
   // Par contre, le KeyPressMask est bien sur glzone car le focus est
   // *explicitement* redirige sur cette zone par glzoneSetFocusEH & co.
 
-  XtAddEventHandler(gui->toplevel, ButtonPressMask, False,
+  XtAddEventHandler(gui.toplevel, ButtonPressMask, False,
 		    glzoneMousePressEH, (XtPointer)this);
   // move avec bouton defonce
-  //XtAddEventHandler(gui->toplevel, PointerMotionMask, False,
+  //XtAddEventHandler(gui.toplevel, PointerMotionMask, False,
   //		    glzoneMouseMoveEH, (XtPointer)this);
 
   // The rightpanel that contains both lists
@@ -421,25 +417,25 @@ GuiWidgets::GuiWidgets(GUI *pgui) {
   //		    (XtPointer)this);
 
 
-  XtRealizeWidget(gui->toplevel);
+  XtRealizeWidget(gui.toplevel);
   Position top_rootx, top_rooty, glzone_rootx, glzone_rooty;
 
-  XtTranslateCoords(gui->toplevel, 0, 0, &top_rootx, &top_rooty);
+  XtTranslateCoords(gui.toplevel, 0, 0, &top_rootx, &top_rooty);
   XtTranslateCoords(glzone, 0, 0, &glzone_rootx, &glzone_rooty);
   glwin_x = glzone_rootx - top_rootx;
   glwin_y = glzone_rooty - top_rooty;
 
-  XtSetKeyboardFocus(gui->toplevel, glzone);
+  XtSetKeyboardFocus(gui.toplevel, glzone);
 
   // moveBar not available in this version
   moveBar = NULL;
 
 #ifndef WANT_MOTIF
   // necessaire pour Athena
-  initTogglePixmap(gui->toplevel);
-  XtVaSetValues(rightPanel, XtNheight, (XtArgVal)resources.height3D, NULL);
-  XtVaSetValues(worldsPane, XtNmin, (XtArgVal)resources.height3D/3, NULL);
-  XtVaSetValues(usersPane,  XtNmin, (XtArgVal)resources.height3D/3, NULL);
+  initTogglePixmap(gui.toplevel);
+  XtVaSetValues(rightPanel, XtNheight, (XtArgVal)options->height3D, NULL);
+  XtVaSetValues(worldsPane, XtNmin, (XtArgVal)options->height3D/3, NULL);
+  XtVaSetValues(usersPane,  XtNmin, (XtArgVal)options->height3D/3, NULL);
 #endif
 }
 
@@ -453,8 +449,8 @@ void GuiWidgets::resizeGLZone(int width, int height) {
 #ifndef WANT_MOTIF
   // necessaire pour Athena
   XtVaSetValues(rightPanel, XtNheight, (XtArgVal)height, NULL);
-  XtVaSetValues(worldsPane, XtNmin, (XtArgVal)resources.height3D/3, NULL);
-  XtVaSetValues(usersPane,  XtNmin, (XtArgVal)resources.height3D/3, NULL);
+  XtVaSetValues(worldsPane, XtNmin, (XtArgVal)options->height3D/3, NULL);
+  XtVaSetValues(usersPane,  XtNmin, (XtArgVal)options->height3D/3, NULL);
 #endif
 }
 
@@ -510,6 +506,7 @@ static Widget CreateButtonAndOptionMenu(Widget menubar, String name) {
   CreateSeparator(menu, "separ");
 
   n = 0 ;
+  CreateRadio(menu, "Mozilla", &n,radiogroup3, GUI::setPref, MOZILLA_TOOL);
   CreateRadio(menu, "Netscape",&n,radiogroup3, GUI::setPref, NETSCAPE_TOOL);
   CreateRadio(menu, "mMosaic", &n,radiogroup3, GUI::setPref, MMOSAIC_TOOL);
   radiogroup3[n] = NULL;
@@ -543,12 +540,12 @@ static Widget CreateButtonAndOptionMenu(Widget menubar, String name) {
 
 void GuiWidgets::glzoneSetFocusEH(Widget w, XtPointer cld, XEvent *xe, Boolean*){
   GuiWidgets *gw = (GuiWidgets*)cld;
-  XtSetKeyboardFocus(gw->gui->toplevel, gw->glzone);
+  XtSetKeyboardFocus(gw->gui.toplevel, gw->glzone);
 }
 
 void GuiWidgets::entrySetFocusEH(Widget w, XtPointer cld, XEvent *xe, Boolean*){
   GuiWidgets *gw = (GuiWidgets*)cld;
-  XtSetKeyboardFocus(gw->gui->toplevel, gw->entry);
+  XtSetKeyboardFocus(gw->gui.toplevel, gw->entry);
 }
 
 // There is no Activate callback (ie when pressing Return) in Athena
@@ -581,9 +578,9 @@ void GuiWidgets::entryActionCB(Widget, XtPointer cld, XtPointer) {
   *out = '\0';
 
   // display in message zone
-  gw->writeMessage("chat", resources.nick, buf);
+  gw->writeMessage("chat", options->nick, buf);
   // send to World Management 
-  userWriting(buf);
+  User::userWriting(buf);
 
   SetTextFieldValue(gw->entry, "");   // clear input zone 
   XtFree(mess);
@@ -597,7 +594,7 @@ void GuiWidgets::glzoneKeyPressEH(Widget, XtPointer cld,
 				  XEvent *xe, Boolean*) {
   GuiWidgets *gw = (GuiWidgets*)cld;
   // gets the X Keysym
-  gw->gui->processKey(XKeycodeToKeysym(xe->xany.display, xe->xkey.keycode, 0),
+  gw->gui.processKey(XKeycodeToKeysym(xe->xany.display, xe->xkey.keycode, 0),
 		  TRUE);
 }
 
@@ -605,7 +602,7 @@ void GuiWidgets::glzoneKeyReleaseEH(Widget, XtPointer cld,
 				    XEvent *xe, Boolean*) {
   GuiWidgets *gw = (GuiWidgets*)cld;
   // gets the X Keysym
-  gw->gui->processKey(XKeycodeToKeysym(xe->xany.display, xe->xkey.keycode, 0),
+  gw->gui.processKey(XKeycodeToKeysym(xe->xany.display, xe->xkey.keycode, 0),
 		      FALSE);
 }
 
@@ -615,7 +612,7 @@ void GuiWidgets::glzoneMouseMoveEH(Widget, XtPointer cld,
 				    XEvent *xe, Boolean*) {
   if (followMouseMode) {
     ObjInfo objinfo[BUTTONSNUMBER + 6];
-    struct _ZVSolid *solid =
+    VGLSolid *solid =
       GUI::getPointedObject(xe->xbutton.x, xe->xbutton.y, objinfo);
 
     // 2nd arg is false ==> the popup menu is NOT created
@@ -630,10 +627,10 @@ void GuiWidgets::glzoneMousePressEH(Widget, XtPointer cld,
   xe->xbutton.x -= gw->glwin_x;
   xe->xbutton.y -= gw->glwin_y;
 
-  XtSetKeyboardFocus(gw->gui->toplevel, gw->glzone);  //securite
+  XtSetKeyboardFocus(gw->gui.toplevel, gw->glzone);  //securite
 
   ObjInfo objinfo[BUTTONSNUMBER + 6];
-  struct _ZVSolid *solid =
+  VGLSolid *solid =
     GUI::selectPointedObject(xe->xbutton.x, xe->xbutton.y, objinfo);
 
   if (solid) {
@@ -650,7 +647,7 @@ void GuiWidgets::glzoneMousePressEH(Widget, XtPointer cld,
 // updates the ObjectBar (and the ObjectMenu when available)
 // NB: removes and delete both if argument is NULL
 
-void GuiWidgets::updateObjectInfo(ObjInfo *objinfo, boolean createMenu) {
+void GuiWidgets::updateObjectInfo(ObjInfo *objinfo, int createMenu) {
   if (!objinfo) {
     if (objectBar) XtDestroyWidget(objectBar);
     objectBar = NULL;
@@ -776,39 +773,37 @@ void GuiWidgets::writeMessage(const char *mode, const char *from, const char *me
   free(buf);
 }
 
-void GuiWidgets::showAlertBox(boolean state) {}
 
-
-void GuiWidgets::updateUser(GuiUser gu, struct User *puser) {
-  SetLabelValue(gu, puser->name.instance_name);
+void GuiWidgets::updateUser(UBox *gu, User *user) {
+  SetLabelValue(gu, user->name.instance_name);
 }
 
-GuiUser GuiWidgets::addUser(struct User *puser) {
-  GuiUser gu = CreateLabel(users, "userItem");
-  SetLabelValue(gu, puser->name.instance_name);
+UBox * GuiWidgets::addUser(User *user) {
+  UBox * gu = CreateLabel(users, "userItem");
+  SetLabelValue(gu, user->name.instance_name);
   XtManageChild(gu);
   return gu;
 }
 
-void GuiWidgets::removeUser(GuiUser gu) {
+void GuiWidgets::removeUser(UBox * gu) {
   XtDestroyWidget(gu);
 }
 
 
-GuiWorld GuiWidgets::addWorld(struct _World *pworld, boolean isCurrentWorld) {
- GuiWorld gw = CreateLabel(worlds, "worldItem");
- SetLabelValue(gw, pworld->name);
+UBox * GuiWidgets::addWorld(World *world, boolean isCurrent) {
+ UBox * gw = CreateLabel(worlds, "worldItem");
+ SetLabelValue(gw, world->name);
  XtManageChild(gw);
  return gw;
 }
 
-void GuiWidgets::updateWorld(struct _World *pworld, boolean isCurrentWorld) {
-  GuiWorld gw = (GuiWorld) pworld->ptrgui;
-  SetLabelValue(gw, pworld->name);
+void GuiWidgets::updateWorld(World *world, boolean isCurrent) {
+  UBox * gw = world->guip;
+  SetLabelValue(gw, world->name);
 }
 
-void GuiWidgets::removeWorld(struct _World *pworld) {
-  GuiWorld gw = (GuiWorld) pworld->ptrgui;
+void GuiWidgets::removeWorld(World *world) {
+  UBox * gw = world->guip;
   XtDestroyWidget(gw);
 }
 
@@ -871,6 +866,18 @@ static void delCallData(Widget w, XtPointer cld, XtPointer) {
   delete cd;
 }
 
+void GuiWidgets::redirectToVnc(class Vnc* _vnc) {
+  vnc = _vnc;
+}
+
+void GuiWidgets::alert(const char* message) {
+}
+
+void GuiWidgets::launchVncConnect(Vnc *po) {
+}
+
+void GuiWidgets::initVncConnect(Vnc *po) {
+}
 
 // INTERACTEURS
 
@@ -1058,7 +1065,7 @@ static char *GetTextFieldValue(Widget ww)  {
   return s;
 }
 
-static void SetTextAreaValue(Widget ww, const char *s, boolean add_at_the_end) {
+static void SetTextAreaValue(Widget ww, const char *s, bool add_at_the_end) {
 #if WANT_MOTIF
   XmTextPosition lastpos = XmTextGetLastPosition(ww);
   if (!add_at_the_end) 
@@ -1092,7 +1099,7 @@ static void SetTextAreaValue(Widget ww, const char *s, boolean add_at_the_end) {
 }
 
 
-char** GuiWidgets::getFallbackResources() {
+char** GuiWidgets::getFallbackOptions() {
   static char* fallbacks[] = {
     "*menuBar*fontList: -*-helvetica-bold-r-normal-*-12-*-*-*-*-*-*-1",
     "*toolBar*fontList: -*-helvetica-bold-o-normal-*-12-*-*-*-*-*-*-1",
@@ -1142,5 +1149,3 @@ char** GuiWidgets::getFallbackResources() {
   return fallbacks;
 }
 
-
-#endif /* !VRENGD */ 
