@@ -1,25 +1,16 @@
-/*
-   File     : guimisc.c
-   Author   : Philippe Dax
-   Creation : 04/12/98
-*/
-
 #include "global.h"
-#include "zv.h"		/* RenderClose */
-#include "stat.h"	/* statNetwork */
-#include "net.h"
-#include "world.h"
-#include "wobject.h"
-#include "ifc.h"
-#include "guimisc.h"
+#include "vgl.h"	// VglQuit
+#include "net.h"	// NetQuit
+#include "world.h"	// WoQuit
 
+extern int my_wait(pid_t);
 
-/* Local variables */
+/* Local variable */
 static int inquit;
 
 
-/* quit VREng */
-void QuitVreng(int i)
+/** quit VREng */
+void quitVreng(int i)
 {  
   if (inquit) {
     trace(DBG_FORCE, "quit: inquit=%d sig=%d", inquit, i);
@@ -32,14 +23,10 @@ void QuitVreng(int i)
   }
   inquit++;
 
-#ifndef VRENGD
   /* Close modules */
-
-  //ifcKillChildren();
-  RenderClose();
-  quitWMgt();
-  statNetwork();
-#endif /* !VRENGD */
+  VglQuit();
+  World::terminate();
+  NetQuit();
 
   /* quit if i!=0 (to eventually call Xerrors) */
   if (i) exit(i);
@@ -49,16 +36,16 @@ static
 void quitSig(int sig)
 {
   fprintf(stderr, "Got signal %d, aborting VREng.\n", sig);
-  QuitVreng(sig);
+  quitVreng(sig);
 }
 
 #ifndef WIN32
 static
 void reapchild(int sig)
 {
-  my_wait();
+  my_wait(-1);
 }
-#endif /* !WIN32 */
+#endif // !WIN32
 
 void initSignals(void)
 {
@@ -69,5 +56,5 @@ void initSignals(void)
   signal(SIGBUS, quitSig);
   signal(SIGSEGV, quitSig);
   signal(SIGCHLD, reapchild);
-#endif /* !WIN32 */
+#endif // !WIN32
 }
